OiRA

Help

1. Προετοιμασία
2. Συμμετοχή των εργαζομένων
3. Αναγνώριση + Αξιολόγηση
4. Σχέδιο Δράσης
   1. 1.1.1 Slips, trips and falls are not prevented.
   2. 1.1.2 Collisions, bumps, and jamming are not prevented.
   3. 1.1.4 Exposure to noise is neither prevented nor controlled.
   4. 1.1.6 Exposure to biological substances is neither prevented nor controlled
   5. Ω.1 The entrance floor is often wet
   6. Title of the first custom risk
   7. This is another custom risk added by the user
   - Προσοχή κίνδυνος!
5. Έκθεση
6. Παρούσα Κατάσταση 9%

# Commercial guarding, Leicester

Μέχρι το σημείο αυτό, έχουν αναγνωριστεί οι κίνδυνοι και έχει αξιολογηθεί η επικινδυνότητά τους. Το επόμενο βήμα είναι να συνταχθεί και να εφαρμοστεί ένα Σχέδιο Δράσης με σκοπό την αποτελεσματική διαχείριση των κινδύνων στην πράξη. Για την ελαχιστοποίηση/εξάλειψη ή τη μείωσή τους, στη φάση αυτή χρειάζεται να ληφθεί απόφαση σχετικά με το ποια είναι τα κατάλληλα μέτρα πρόληψης και προστασίας που απαιτείται να εφαρμοστούν, λαμβάνοντας υπόψη, μεταξύ άλλων, θέματα όπως:

1. Μπορεί ο κίνδυνος να αποφευχθεί; Μπορεί να εξαλειφθεί εντελώς; Για παράδειγμα, αυτό μπορεί να επιτευχθεί:
   - εξετάζοντας εάν η συγκεκριμένη εργασία είναι απαραίτητη,
   - εξαλείφοντας τον κίνδυνο (με αποτελεσματική παρέμβαση στην πηγή του).
2. Εάν ορισμένοι κίνδυνοι είναι αναπόφευκτοι, πώς αυτοί μπορούν να μειωθούν σε επίπεδο στο οποίο δεν διακυβεύεται πλέον η υγεία και η ασφάλεια όσων εκτίθενται σε αυτούς;

Μόλις ληφθεί απόφαση για το πώς θα εξαλειφθεί ή θα μειωθεί ένας συγκεκριμένος κίνδυνος, τότε μπορεί πλέον να περιγραφούν οι συγκεκριμένες ενέργειες που απαιτούνται για να επιτευχθεί κάτι τέτοιο. Θα πρέπει επίσης να συμπεριληφθούν λεπτομέρειες για το επίπεδο τεχνογνωσίας ή/και τις υπόλοιπες προϋποθέσεις που απαιτούνται ώστε αυτές οι ενέργειες να είναι αποτελεσματικές.

Δημιουργία σχεδίου δράσης

Scroll to top
Back

## action-plan-landing.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More